-------------------------------------------------------
-- DB Version        _      __     __     __
--                  / |    /_ \   /  \   /  \
--                   ||    _|.|   |()|   |()|
--                  |__| o \__/ o \__/ o \__/
-------------------------------------------------------
CREATE TABLE [DbProperties] ([Key] ntext NOT NULL,	[Value] ntext);
INSERT INTO [DbProperties]([Key], [Value]) VALUES ('Version', '1.3.0.0');

--  Create Tables 
CREATE TABLE [UnsentAlarms] ( 
	[ID] int identity(1,1)  NOT NULL,
	[BusinessActionId] int NOT NULL,
	[AlarmInstanceId] int NOT NULL,
	[Timestamp] datetime NOT NULL,
	[BeforeExternal] smallint NOT NULL,
	[BeforeInternal] smallint NOT NULL,
	[AfterExternal] smallint NOT NULL,
	[AfterInternal] smallint NOT NULL
)
;

CREATE TABLE [AlarmActions] ( 
	[ID] int identity(1,1)  NOT NULL,
	[IDAlarmInstances] int NOT NULL,
	[IDAlarmCategory] int,
	[IDBusinessAction] int NOT NULL,
	[Transition] smallint NOT NULL,
	[RoutingStatus] smallint NOT NULL,
	[RetryCount] smallint NOT NULL,
	[RetriesLeft] smallint NOT NULL,
	[Timestamp] datetime NOT NULL
)
;

CREATE TABLE [AlarmStatuses] ( 
	[ID] int identity(1,1)  NOT NULL,
	[IDAlarmInstances] int NOT NULL,
	[Timestamp] datetime NOT NULL,
	[InternalStatus] smallint NOT NULL,
	[ExternalStatus] smallint NOT NULL
)
;

CREATE TABLE [AlarmInstances] ( 
	[ID] int identity(1,1)  NOT NULL,
	[ResourceCoordinates] ntext,
	[InstanceBegin] datetime,
	[InstanceEnd] datetime,
	[InstanceCreated] datetime NOT NULL
)
;


--  Create Primary Key Constraints 
ALTER TABLE [UnsentAlarms] ADD CONSTRAINT [PK_UnsentAlarms] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [AlarmActions] ADD CONSTRAINT [PK_AlarmActions] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [AlarmStatuses] ADD CONSTRAINT [PK_AlarmStatuses] 
	PRIMARY KEY  ([ID])
;

ALTER TABLE [AlarmInstances] ADD CONSTRAINT [PK_Alarm] 
	PRIMARY KEY  ([ID])
;



--  Create Foreign Key Constraints 
ALTER TABLE [AlarmActions] ADD CONSTRAINT [FK_AlarmInstances] 
	FOREIGN KEY ([IDAlarmInstances]) REFERENCES [AlarmInstances] ([ID]) ON DELETE CASCADE
;

ALTER TABLE [AlarmStatuses] ADD CONSTRAINT [FK_AlarmInstances] 
	FOREIGN KEY ([IDAlarmInstances]) REFERENCES [AlarmInstances] ([ID])	ON DELETE CASCADE
;


-- Create Indexes
CREATE INDEX [IDX_FK_AlarmInstances]
ON [AlarmActions] ([IDAlarmInstances] ASC)
;

CREATE INDEX [IDX_AlarmStatuses_Timestamp]
ON [AlarmStatuses] ([Timestamp] ASC)
;

CREATE INDEX [IDX_AlarmInstances_InstanceCreated]
ON [AlarmInstances] ([InstanceCreated] ASC)
;

CREATE INDEX [IDX_AlarmInstances_InstanceEnd]
ON [AlarmInstances] ([InstanceEnd] ASC)
;

CREATE INDEX [IDX_AlarmInstances_InstanceBegin]
ON [AlarmInstances] ([InstanceBegin] ASC)
;