function createTable(panelContainer, headers) {
    var table = new Element('table', { 'class': 'simpleTable' });
    table.set('cellpadding', '0');
    table.set('cellspacing', '0');
    table.inject(panelContainer);
    var thead = new Element('thead', {});
    thead.inject(table);
    var trH = new Element('tr', {});
    trH.inject(thead);
    for (var i = 0; i < headers.length; i++) {
        var th = new Element('th', { html: headers[i] });
        th.inject(trH);
    }
    var tbody = new Element('tbody', {});
    tbody.inject(table);
    return tbody;
}
var manageArgs = true;
var myClientDataEntry;
var argsTextWidth = "80px";
var ARGS_SEPARATOR = '|';
var COMMAND_SEPARATOR = '#';
var GROUP_SEPARATOR = '@';
var ITEM_SEPARATOR = '$';

var commandArgumentsManager = {
    initialize: function() {
        $('decCommand').addEvent('change', commandArgumentsManager.buildArgs);
    },

    setArguments: function(prefix, values) {
        for (i = 0; i < values.length; i++) {
            var currentControl = $(prefix + i);
            if (currentControl != null) {
                $(currentControl).value = values[i];
            }
        }
    },

    buildArgs: function(ddlName, target, prefix) {
        if (manageArgs) {
            var ddlName = "decCommand";
            var target = "gArgs";
            var prefix = "decArg";
            var ddlCommands = $(ddlName);
            if (ddlCommands.selectedIndex != -1) {
                var selectedCommandID = ddlCommands.options[ddlCommands.selectedIndex].value;
                var postBody = "modality=ajax" + "&exec=getArgumentsHTML" + "&commandID=" + selectedCommandID;
                new Request({ url: '/SchedulerActionCommandInvocation.rix',
                    onComplete: function(request) {
                        commandArgumentsManager.insertArguments(request, target, prefix);
                    },
                    timeout: 5000
                }).send(postBody);
            }
        }
    },

    insertArguments: function(argumentList, target, prefix) {
        if (manageArgs) {
            var table = $(target);
            var argsArray = (argumentList == "" || argumentList == null) ? new String() : argumentList.split(ITEM_SEPARATOR);
            var currentRow = 0;
            argsControls = new Array();

            for (var i = table.rows.length; i > 0; i--) {
                table.deleteRow(i - 1);
            }

            for (i = 0; i < argsArray.length; i++) {
                var newRow = table.insertRow(-1);
                newRow.className = 'inputtext';
                var headerCell = document.createElement('th');
                headerCell.innerHTML = "<label>" + argsArray[i] + "</label>";
                newRow.appendChild(headerCell, textCell);
                var textCell = document.createElement('td');
                textCell.innerHTML = "<input style=\"width:" + argsTextWidth + "\" type=\"text\" value=\"\" id=\"" + prefix + i + "\" name=\"" + prefix + i + "\" />";
                newRow.appendChild(textCell);
            }
        }
    },

    loadDataEdit: function() {
        var selectedType = $('cActionType').selectedIndex;
        if (selectedType == 0) {
            var actionID = myClientDataEntry.getRecordID();
            var postBody = "modality=ajax" + "&exec=loadData" + "&actionID=" + actionID;
            new Request({ url: '/SchedulerActionCommandInvocation.rix',
                onComplete: function(request) {
                    var ddlCommand = $('decCommand');
                    ddlCommand.removeEvent('change', commandArgumentsManager.buildArgs);
                    var group = request.split(GROUP_SEPARATOR);
                    var args = group[2].split(ARGS_SEPARATOR);
                    selectValue(ddlCommand, group[0]);
                    if (manageArgs) {
                        commandArgumentsManager.insertArguments(group[1], 'gArgs', 'decArg');
                        commandArgumentsManager.setArguments('decArg', args);
                    }
                    ddlCommand.addEvent('change', commandArgumentsManager.buildArgs);
                },
                timeout: 5000
            }).send(postBody);
        }
    }
};

var filterManager = {
    initialize: function(selectorTypes, resourceTypes, interfaceAttributes, deviceAttributes, interfaces, uiDictionary, nodesDictionary) {

        filterManager.previewTree = new Jx.Tree({ parent: 'treeFilterArea' });

        this.textArea = $('cFilters');
        this.localizeNodes = false;
        this.nodesDictionary = nodesDictionary;
        this.uiDictionary = uiDictionary;

        this.editList = $('nodeList');
        this.nodeArray = new Array();

        $('btnManageFilters').addEvent('click', filterManager.editData);
        $('modalPopUpContainer').addEvent('click', filterManager.closeModalPopUp);

        filterManager.localizeUI(uiDictionary, nodesDictionary);

        filterManager.loadData();
        filterManager.hideAll();

        filterManager.initializeSelectorDDL(selectorTypes);
        filterManager.initializeResourceDDL(resourceTypes);
        filterManager.initializeInterfaceAttributeDDL(interfaceAttributes);
        filterManager.initializeDeviceAttributeDDL(deviceAttributes);
        filterManager.initializeDeviceInterfacesDDL(interfaces);
        //                filterManager.initializeSelectorCheckBoxs(selectorResxTypes);

        $('btnPopUpFiltersClose').addEvent('click', filterManager.closeModalPopUp);
        $('btnPopUpFiltersSave').addEvent('click', filterManager.saveFilters);

        $('btn_add_selector').addEvent('click', filterManager.addNodeSelector);
        $('btn_save_selector').addEvent('click', filterManager.saveNodeSelector);
        $('btn_save_interface').addEvent('click', filterManager.saveNodeInterface);
        $('btn_save_device').addEvent('click', filterManager.saveNodeDevice);
        $('btn_save_resource').addEvent('click', filterManager.saveNodeResource);

        $('ddl_attr_interface').addEvent('change', filterManager.attributeInterfaceChange);
        $('ddl_attr_device').addEvent('change', filterManager.attributeDeviceChange);
        $('ddl_interface_device').addEvent('change', filterManager.attributeDeviceChange);

        $('btn_set_device').addEvent('click', filterManager.setDeviceValue);
        $('btn_set_interface').addEvent('click', filterManager.setInterfaceValue);

        $('btn_set_device').set('disabled', 1);
        $('btn_set_interface').set('disabled', 1);

        $('val_id_resource').setStyle('display', 'none');
        $('val_id_interface').setStyle('display', 'none');
        $('val_name_interface').setStyle('display', 'none');
        $('val_address_device').setStyle('display', 'none');

        $('pl_icon_quick_interface').setStyle('display', 'none');
        $('pl_icon_quick_device').setStyle('display', 'none');
    },

    attributeInterfaceChange: function() {
        var ddl = $('ddl_attr_interface');
        var currentAttribute = ddl.get('value');
        if (currentAttribute == '') {
            $('ddl_value_interface').options.length = 0;
            $('btn_set_interface').set('disabled', 1);
            return;
        }
        // Call Option Update
        $('pl_icon_quick_interface').setStyle('display', '');

        var param = "modality=ajax" + "&exec=getInterfaces" + "&argumentID=" + currentAttribute;
        new Request(
                {
                    url: '/SchedulerActionCommandInvocation.rix',
                    onComplete: function(request) {
                        var list = JSON.decode(request);
                        if (list.length > 0) {
                            filterManager.addOptionsToSelect('ddl_value_interface', list, true);
                            $('btn_set_interface').set('disabled', 0);
                        } else {
                            filterManager.addOptionsToSelect('ddl_value_interface', [{ id: '', display: uiDictionary["nodata"]}], true);
                            $('btn_set_interface').set('disabled', 1);
                        }
                        filterManager.addOptionsToSelect('ddl_value_interface', list, true);
                        $('btn_set_interface').set('disabled', 0);
                        $('pl_icon_quick_interface').setStyle('display', 'none');
                    },
                    timeout: 5000
                }).send(param);
    },

    attributeDeviceChange: function() {
        var ddlAttr = $('ddl_attr_device');
        var ddlInterface = $('ddl_interface_device');
        var currentAttribute = ddlAttr.get('value');
        var currentInterface = ddlInterface.get('value');

        if (currentAttribute == '' || currentInterface == '') {
            $('ddl_value_device').options.length = 0;
            $('btn_set_device').set('disabled', 1);
            return;
        }
        $('pl_icon_quick_device').setStyle('display', '');
        var param = "modality=ajax" + "&exec=getDevices" + "&argumentID=" + currentAttribute + "&interfaceID=" + currentInterface;
        new Request(
                {
                    url: '/SchedulerActionCommandInvocation.rix',
                    onComplete: function(request) {
                        var list = JSON.decode(request);
                        if (list.length > 0) {
                            filterManager.addOptionsToSelect('ddl_value_device', list, true);
                            $('btn_set_device').set('disabled', 0);
                        } else {
                            filterManager.addOptionsToSelect('ddl_value_device', [{ id: '', display: uiDictionary["nodata"]}], true);
                            $('btn_set_device').set('disabled', 1);
                        }
                        $('pl_icon_quick_device').setStyle('display', 'none');
                    },
                    timeout: 5000
                }).send(param);
    },

    setDeviceValue: function() {
        var destAttr = $('ddl_attr_device').get('value');
        var value = $('ddl_value_device').get('value');
        switch (destAttr) {
            case "name":
                $('filter_device_name').set('value', value);
                break;
            case "model":
                $('filter_device_model').set('value', value);
                break;
            case "address":
                $('filter_device_address').set('value', value);
                break;
            default:
                break;
        }
    },

    setInterfaceValue: function() {
        var destAttr = $('ddl_attr_interface').get('value');
        var value = $('ddl_value_interface').get('value');
        switch (destAttr) {
            case "id":
                $('filter_interface_id').set('value', value);
                break;
            case "name":
                $('filter_interface_name').set('value', value);
                break;
            default:
                break;
        }
    },

    localizeUI: function(uiDictionary, nodesDictionary) {
        $('btn_add_selector').set('html', uiDictionary["addSelector"]);

        $('btn_save_selector').set('value', uiDictionary["save"]);
        $('btn_save_interface').set('value', uiDictionary["save"]);
        $('btn_save_device').set('value', uiDictionary["save"]);
        $('btn_save_resource').set('value', uiDictionary["save"]);

        $('btn_set_device').set('value', uiDictionary["setvalue"]);
        $('btn_set_interface').set('value', uiDictionary["setvalue"]);

        $('title_filterSelector').set('html', uiDictionary["filter"]);
        $('title_filterInterface').set('html', uiDictionary["filter"]);
        $('title_filterDevice').set('html', uiDictionary["filter"]);
        $('title_filterResource').set('html', uiDictionary["filter"]);

        $('title_quickSetDevice').set('html', uiDictionary["quickSet"]);
        $('title_quickSetInterface').set('html', uiDictionary["quickSet"]);

        $('title_attributeInterface').set('html', uiDictionary["attribute"]);
        $('title_valueInterface').set('html', uiDictionary["value"]);

        $('title_attributeDevice').set('html', uiDictionary["attribute"]);
        $('title_interfaceDevice').set('html', uiDictionary["interface"]);
        $('title_valueDevice').set('html', uiDictionary["value"]);
        $('title_filterList').set('html', uiDictionary["filterlist"]);

        $('val_id_resource').set('alt', uiDictionary["tooltip_validation_resource_id"]);
        $('val_id_interface').set('alt', uiDictionary["tooltip_validation_interface_id"]);
        $('val_name_interface').set('alt', uiDictionary["tooltip_validation_interface_name"]);
        $('val_address_device').set('alt', uiDictionary["tooltip_validation_device_address"]);
        $('val_id_resource').set('title', uiDictionary["tooltip_validation_resource_id"]);
        $('val_id_interface').set('title', uiDictionary["tooltip_validation_interface_id"]);
        $('val_address_device').set('title', uiDictionary["tooltip_validation_device_address"]);

        $('label_type_selector').set('html', nodesDictionary["type"]);
        $('label_resources_selector').set('html', nodesDictionary["resources"]);
        $('label_id_interface').set('html', nodesDictionary["id"]);
        $('label_name_interface').set('html', nodesDictionary["name"]);
        $('label_address_device').set('html', nodesDictionary["address"]);
        $('label_name_device').set('html', nodesDictionary["name"]);
        $('label_model_device').set('html', nodesDictionary["model"]);
        $('label_id_resource').set('html', nodesDictionary["id"]);
        $('label_name_resource').set('html', nodesDictionary["name"]);
        $('label_type_resource').set('html', nodesDictionary["type"]);
    },

    createCheckBox: function(divID, options) {
        var elDiv = $(divID);
        for (var index = 0; index < options.length; index++) {

            var cb = new Element('input', { type: 'checkbox', value: options[index].id });
            var span = new Element('span');
            span.set('html', options[index].display);
            var br = new Element('br');
            cb.inject(elDiv);
            span.inject(elDiv);
            br.inject(elDiv);
        }
    },

    addOptionsToSelect: function(selectID, options, clearBeforeInsert) {
        var elSel = $(selectID);
        if (clearBeforeInsert)
            elSel.options.length = 0;
        for (var index = 0; index < options.length; index++) {
            var elOptNew = document.createElement('option');
            elOptNew.text = options[index].display;
            elOptNew.value = options[index].id;
            try {
                elSel.add(elOptNew, null);
            }
            catch (ex) {
                elSel.add(elOptNew);
            }
        }
    },

    initializeInterfaceAttributeDDL: function(attributes) {
        filterManager.addOptionsToSelect('ddl_attr_interface', [{ id: '', display: filterManager.uiDictionary["select"]}], false);
        filterManager.addOptionsToSelect('ddl_attr_interface', attributes, false);
    },

    initializeDeviceAttributeDDL: function(attributes) {
        filterManager.addOptionsToSelect('ddl_attr_device', [{ id: '', display: filterManager.uiDictionary["select"]}], false);
        filterManager.addOptionsToSelect('ddl_attr_device', attributes, false);
    },

    initializeDeviceInterfacesDDL: function(interfaces) {
        filterManager.addOptionsToSelect('ddl_interface_device', [{ id: '', display: filterManager.uiDictionary["select"]}], false);
        filterManager.addOptionsToSelect('ddl_interface_device', interfaces, false);
    },

    initializeResourceDDL: function(resourceTypes) {
        filterManager.addOptionsToSelect('ddl_type_resource', resourceTypes, false);
    },

    initializeSelectorDDL: function(selectorTypes) {
        filterManager.addOptionsToSelect('ddl_type_selector', selectorTypes, false);
    },

    //            initializeSelectorCheckBoxs: function(selectorResxTypes) {
    //                filterManager.createCheckBox('checkboxs_resource_selector', selectorResxTypes, false);
    //            },

    loadData: function() {
        filterManager.getXMLFilters();
        filterManager.displayDataPreview();
    },

    getAttributesString: function(xmlNode) {
        var dataString = "";
        for (var index = 0; index < xmlNode.attributes.length; index++) {
            var att = xmlNode.attributes[index];
            if (filterManager.nodesDictionary[att.name] != null)
                dataString += filterManager.nodesDictionary[att.name] + '="' + att.value + '" ';
            else
                dataString += att.name + '="' + att.value + '" ';
        }
        return dataString;
    },

    hideAll: function() {
        $('selectorEdit').setStyle('display', 'none');
        $('interfaceEdit').setStyle('display', 'none');
        $('deviceEdit').setStyle('display', 'none');
        $('resourceEdit').setStyle('display', 'none');
    },

    switchUI: function(tagName) {
        filterManager.hideAll();
        switch (tagName) {
            case "selector":
                $('selectorEdit').setStyle('display', '');
                break;
            case "interface":
                $('interfaceEdit').setStyle('display', '');
                break;
            case "device":
                $('deviceEdit').setStyle('display', '');
                break;
            case "resource":
                $('resourceEdit').setStyle('display', '');
                break;
            default:
        }
    },

    setAttribute: function(node, attributeName, value) {
        var attribute = node.getAttributeNode(attributeName);
        if (value == "" && attribute != null) {
            node.removeAttribute(attributeName);
            return;
        }
        if (value == "")
            return;
        if (attribute == null) {
            attribute = filterManager.xmlDoc.createAttribute(attributeName);
            attribute.nodeValue = value;
            node.setAttributeNode(attribute);
        } else {
            attribute.nodeValue = value;
        }
    },

    getAttribute: function(node, attributeName) {
        var attribute = node.getAttribute(attributeName);
        if (attribute != null)
            return attribute;
        return '';
    },

    saveNodeSelector: function() {
        var node = filterManager.currentNode;
        filterManager.setAttribute(node, 'type', $('ddl_type_selector').get('value'));

        var checkBoxs = $('checkboxs_resource_selector').getElements('input');

        var nodeValue = "";

        checkBoxs.each(function(control) {
            if (control.checked)
                nodeValue = nodeValue + control.get('value') + ' ';
        });

        var resxNode = node.getElementsByTagName('resourceTypes');
        if (nodeValue.length > 0) {
            nodeValue = nodeValue.substring(0, nodeValue.length - 1);
            if (resxNode.length <= 0) {
                var newNode = filterManager.xmlDoc.createElement('resourceTypes');
                if (document.all) {
                    newNode.text = nodeValue;
                } else {
                    newNode.textContent = nodeValue;
                }
                node.appendChild(newNode);
            } else {
                if (document.all) {
                    resxNode[0].text = nodeValue;
                } else {
                    resxNode[0].textContent = nodeValue;
                }
            }
        }
        else {
            if (resxNode.length > 0)
                node.removeChild(resxNode[0]);
        }
        filterManager.refreshEditList();
    },

    saveNodeInterface: function() {
        var interfaceID = $('filter_interface_id').get('value');
        if (interfaceID != "") {
            var re = new RegExp("\\s*(\\*|\\d+)\\s*");
            if (!interfaceID.match(re)) {
                $('val_id_interface').setStyle('display', '');
                return;
            }
        }
        $('val_id_interface').setStyle('display', 'none');

        var interfaceName = $('filter_interface_name').get('value');
        if (interfaceName != "") {
            var re = new RegExp("\\s*([L|l]ogical)|(\\*|COM([\\d\\?]+|\\*)|((\\*|[2\\?][5\\?][0-5\\?]|[2\\?][0-4\\?][\\d\\?]|[0-1\\?][\\d\\?][\\d\\?]|[\\d\\?][\\d\\?]|[\\d\\?])(\\.(\\*|[2\\?][5\\?][0-5\\?]|[2\\?][0-4\\?][\\d\\?]|[0-1\\?][\\d\\?][\\d\\?]|[\\d\\?][\\d\\?]|[\\d\\?])){3}))\\s*");
            if (!interfaceName.match(re)) {
                $('val_name_interface').setStyle('display', '');
                return;
            }
        }
        $('val_name_interface').setStyle('display', 'none');


        var node = filterManager.currentNode;
        filterManager.setAttribute(node, 'id', interfaceID);
        filterManager.setAttribute(node, 'name', $('filter_interface_name').get('value'));
        filterManager.refreshEditList();
    },

    saveNodeDevice: function() {
        var address = $('filter_device_address').get('value');
        if (address != "") {
            var re = new RegExp("\\s*(\\*|([0\\?]?[\\d\\?]|[1\\?][0-5\\?]|\\*):([0\\?]?[\\d\\?]|[1\\?][0-5\\?]|\\*))\\s*");
            if (!address.match(re)) {
                $('val_address_device').setStyle('display', '');
                return;
            }
        }
        $('val_address_device').setStyle('display', 'none');
        var node = filterManager.currentNode;
        filterManager.setAttribute(node, 'name', $('filter_device_name').get('value'));
        filterManager.setAttribute(node, 'model', $('filter_device_model').get('value'));
        filterManager.setAttribute(node, 'address', address);

        filterManager.refreshEditList();
    },

    saveNodeResource: function() {
        var resourceID = $('filter_resource_id').get('value');
        if (resourceID != "") {
            var re = new RegExp("\\s*(\\*|([A-Z\\?]{3}|\\*)([\\d\\?]{5}|\\*)(:([\\d\\?]+|\\*))?)(-(.+|\\*))?\\s*");
            if (!resourceID.match(re)) {
                $('val_id_resource').setStyle('display', '');
                return;
            }
        }
        $('val_id_resource').setStyle('display', 'none');
        var node = filterManager.currentNode;
        filterManager.setAttribute(node, 'id', resourceID);
        filterManager.setAttribute(node, 'name', $('filter_resource_name').get('value'));
        filterManager.setAttribute(node, 'type', $('ddl_type_resource').get('value'));

        filterManager.refreshEditList();
    },

    loadNodeSelector: function(node) {
        // Load Type
        $('ddl_type_selector').set('value', filterManager.getAttribute(node, 'type'));
        // Load Resxs
        var resxNode = node.getElementsByTagName('resourceTypes');
        var checkBoxs = $('checkboxs_resource_selector').getElements('input');
        if (resxNode.length > 0) {
            var values = "";
            if (document.all) {
                values = resxNode[0].text;
            } else {
                values = resxNode[0].textContent;
            }

            var splitValues = values.split(' ');
            if (splitValues.length > 0) {

                checkBoxs.each(function(control) {
                    if (splitValues.contains('all') || splitValues.contains(control.get('value')))
                        control.checked = true;
                    else
                        control.checked = false;
                });
            }
        } else {
            checkBoxs.each(function(control) {
                control.checked = false;
            });
        }
    },

    loadNodeInterface: function(node) {
        $('filter_interface_id').set('value', filterManager.getAttribute(node, 'id'));
        $('filter_interface_name').set('value', filterManager.getAttribute(node, 'name'));
    },

    loadNodeDevice: function(node) {
        $('filter_device_model').set('value', filterManager.getAttribute(node, 'model'));
        $('filter_device_address').set('value', filterManager.getAttribute(node, 'address'));
        $('filter_device_name').set('value', filterManager.getAttribute(node, 'name'));
    },

    loadNodeResource: function(node) {
        $('filter_resource_id').set('value', filterManager.getAttribute(node, 'id'));
        $('filter_resource_name').set('value', filterManager.getAttribute(node, 'name'));
        $('ddl_type_resource').set('value', filterManager.getAttribute(node, 'type'));
    },

    editNode: function(event, nodeID) {
        filterManager.currentNode = filterManager.nodeArray[nodeID];
        filterManager.switchUI(filterManager.currentNode.tagName);
        switch (filterManager.currentNode.tagName) {
            case "selector":
                filterManager.loadNodeSelector(filterManager.currentNode);
                break;
            case "interface":
                filterManager.loadNodeInterface(filterManager.currentNode);
                break;
            case "device":
                filterManager.loadNodeDevice(filterManager.currentNode);
                break;
            case "resource":
                filterManager.loadNodeResource(filterManager.currentNode);
                break;
            default:
        }
        event.preventDefault();
        return false;
    },

    removeNode: function(event, nodeID) {
        var nodeToRemove = filterManager.nodeArray[nodeID];
        var partentNode = nodeToRemove.parentNode;
        partentNode.removeChild(nodeToRemove);
        filterManager.refreshEditList();
        event.preventDefault();
        return false;
    },

    addNodeSelector: function() {
        var newel = filterManager.xmlDoc.createElement("selector");
        filterManager.xmlDoc.documentElement.appendChild(newel);
        filterManager.refreshEditList();
    },

    addNode: function(event, nodeID) {
        var nodeToExtend = filterManager.nodeArray[nodeID];
        var nodeName = "";
        switch (nodeToExtend.tagName) {
            case "selector":
                nodeName = "interface";
                break;
            case "interface":
                nodeName = "device";
                break;
            case "device":
                nodeName = "resource";
                break;
            default:
        }
        var newel = filterManager.xmlDoc.createElement(nodeName);
        nodeToExtend.appendChild(newel);
        filterManager.refreshEditList();
        event.preventDefault();
        return false;
    },

    moveUpNode: function(event, nodeID) {
        var nodeToMove = filterManager.nodeArray[nodeID];

        if (nodeToMove.previousSibling != null) {
            nodeToMove.parentNode.insertBefore(nodeToMove, nodeToMove.previousSibling);
            filterManager.refreshEditList();
        }
        event.preventDefault();
        return false;
    },

    moveDownNode: function(event, nodeID) {
        var nodeToMove = filterManager.nodeArray[nodeID];

        if (nodeToMove.nextSibling != null) {
            nodeToMove.parentNode.insertBefore(nodeToMove.nextSibling, nodeToMove);
            filterManager.refreshEditList();
        }
        event.preventDefault();
        return false;
    },

    unmarkElement: function(element) {
        element.removeClass('nodeSelected');
    },

    markElement: function(element) {
        element.addClass('nodeSelected');
    },

    addButtons: function(list, nodeID, showAdd, showUpDown, divElement) {
        var btn_d = new Element('div', { 'class': 'filter_buttons' }).inject(list);

        if (showUpDown) {
            var btn_up = new Element('a', { 'class': 'filter_button filter_up', href: '#', title: filterManager.uiDictionary["tooltip_node_up"] }).inject(btn_d);
            btn_up.addEvents({
                click: function(event) { filterManager.moveUpNode(event, nodeID); },
                mouseover: function() { filterManager.markElement(divElement); },
                mouseleave: function() { filterManager.unmarkElement(divElement); }
            });

            var btn_down = new Element('a', { 'class': 'filter_button filter_down', href: '#', title: filterManager.uiDictionary["tooltip_node_down"] }).inject(btn_d);
            btn_down.addEvents({
                click: function(event) { filterManager.moveDownNode(event, nodeID); },
                mouseover: function() { filterManager.markElement(divElement); },
                mouseleave: function() { filterManager.unmarkElement(divElement); }
            });
        }

        if (showAdd) {
            var btn_add = new Element('a', { 'class': 'filter_button filter_add', href: '#', title: filterManager.uiDictionary["tooltip_node_add"] }).inject(btn_d);
            btn_add.addEvents({
                click: function(event) { filterManager.addNode(event, nodeID); },
                mouseover: function() { filterManager.markElement(divElement); },
                mouseleave: function() { filterManager.unmarkElement(divElement); }
            });
        }

        var btn_edit = new Element('a', { 'class': 'filter_button filter_edit', href: '#', title: filterManager.uiDictionary["tooltip_node_edit"] }).inject(btn_d);
        btn_edit.addEvents({
            click: function(event) { filterManager.editNode(event, nodeID); },
            mouseover: function() { filterManager.markElement(divElement); },
            mouseleave: function() { filterManager.unmarkElement(divElement); }
        });

        var btn_remove = new Element('a', { 'class': 'filter_button filter_remove', href: '#', title: filterManager.uiDictionary["tooltip_node_remove"] }).inject(btn_d);
        btn_remove.addEvents({
            click: function(event) { filterManager.removeNode(event, nodeID); },
            mouseover: function() { filterManager.markElement(divElement); },
            mouseleave: function() { filterManager.unmarkElement(divElement); }
        });

        var clear = new Element('div', { styles: { clear: 'both'} }).inject(list);
    },

    refreshEditList: function() {
        filterManager.nodeArray = new Array();
        filterManager.editList.set('html', '');
        var selectors = filterManager.xmlDoc.getElementsByTagName("selector");
        for (var selectorIndex = 0; selectorIndex < selectors.length; selectorIndex++) {
            var row = new Element('div', { 'class': 'filter_edit_item filter_edit_selector' });
            var nodeID = filterManager.nodeArray.length + 1;
            filterManager.nodeArray[nodeID] = selectors[selectorIndex];

            row.set('html', filterManager.nodesDictionary["selector"] + ' ' + filterManager.getAttributesString(selectors[selectorIndex]));
            row.inject(filterManager.editList);

            filterManager.addButtons(filterManager.editList, nodeID, true, true, row);
            var interfaces = selectors[selectorIndex].getElementsByTagName("interface");
            for (var interfaceIndex = 0; interfaceIndex < interfaces.length; interfaceIndex++) {
                var row = new Element('div', { 'class': 'filter_edit_item filter_edit_interface' });
                row.set('html', filterManager.nodesDictionary["interface"] + ' ' + filterManager.getAttributesString(interfaces[interfaceIndex]));
                row.inject(filterManager.editList);
                var nodeID = filterManager.nodeArray.length + 1;
                filterManager.nodeArray[nodeID] = interfaces[interfaceIndex];
                filterManager.addButtons(filterManager.editList, nodeID, true, false, row);

                var devices = interfaces[interfaceIndex].getElementsByTagName("device");
                for (var deviceIndex = 0; deviceIndex < devices.length; deviceIndex++) {
                    var row = new Element('div', { 'class': 'filter_edit_item filter_edit_device' });
                    row.set('html', filterManager.nodesDictionary["device"] + ' ' + filterManager.getAttributesString(devices[deviceIndex]));
                    var nodeID = filterManager.nodeArray.length + 1;
                    filterManager.nodeArray[nodeID] = devices[deviceIndex];
                    row.inject(filterManager.editList);
                    filterManager.addButtons(filterManager.editList, nodeID, true, false, row);

                    var resources = devices[deviceIndex].getElementsByTagName("resource");
                    for (var resourceIndex = 0; resourceIndex < resources.length; resourceIndex++) {
                        var row = new Element('div', { 'class': 'filter_edit_item filter_edit_resource' });
                        row.set('html', filterManager.nodesDictionary["resource"] + ' ' + filterManager.getAttributesString(resources[resourceIndex]));
                        var nodeID = filterManager.nodeArray.length + 1;
                        filterManager.nodeArray[nodeID] = resources[resourceIndex];
                        row.inject(filterManager.editList);
                        filterManager.addButtons(filterManager.editList, nodeID, false, false, row);
                    }
                }
            }
        }
    },

    editData: function() {
        filterManager.refreshEditList();

        filterManager.openModalPopUp();
    },

    saveFilters: function() {
        var xml;
        if (filterManager.xmlDoc.xml == null) {
            xml = (new XMLSerializer()).serializeToString(filterManager.xmlDoc);
        } else {
            xml = filterManager.xmlDoc.xml;
        }

        filterManager.textArea.set('value', xml);
        filterManager.loadData();
        filterManager.closeModalPopUp();
    },

    closeModalPopUp: function() {
        var filteredBkg = $('modalPopUpContainer');
        filteredBkg.style.display = 'none';
        if (Browser.ie6) { // IE6 Z-index BUGFIX
            $('cScheduleType').setStyle('display', '');
            $('cActionType').setStyle('display', '');
            $('cParamType').setStyle('display', '');
            $('cCulture').setStyle('display', '');
        }
        return false;
    },

    openModalPopUp: function() {
        if (Browser.ie6) { // IE6 Z-index BUGFIX
            $('cScheduleType').setStyle('display', 'none');
            $('cActionType').setStyle('display', 'none');
            $('cParamType').setStyle('display', 'none');
            $('cCulture').setStyle('display', 'none');
        }
        $('modalPopUpContainer').style.display = 'block';
        return false;
    },

    attachAttributesTree: function(displayNode, xmlNode) {
        for (var index = 0; index < xmlNode.attributes.length; index++) {
            var att = xmlNode.attributes[index];
            var item = new Jx.TreeItem({
                image: '/media/img/Others/ActionSheduler/attribute.gif',
                label: filterManager.nodesDictionary[att.name] + '=' + att.value
            });
            displayNode.append(item);
        }
    },

    displayDataPreview: function() {
        filterManager.previewTree.clear();
        var selectors = this.xmlDoc.getElementsByTagName("selector");
        for (var selectorIndex = 0; selectorIndex < selectors.length; selectorIndex++) {

            var selectorNode = new Jx.TreeFolder({
                label: filterManager.nodesDictionary["selector"],
                image: '/media/img/Others/ActionSheduler/selector.gif',
                imageClass: 'simpleFolder',
                open: true
            });
            filterManager.attachAttributesTree(selectorNode, selectors[selectorIndex]);
            // Insert Resx Types
            var resxNode = selectors[selectorIndex].getElementsByTagName('resourceTypes');
            var resourceTypes = "";
            if (resxNode.length > 0) {
                if (document.all) {
                    resourceTypes = resxNode[0].text;
                } else {
                    resourceTypes = resxNode[0].textContent;
                }
            }

            if (resourceTypes != "") {
                var item = new Jx.TreeItem({
                    image: '/media/img/Others/ActionSheduler/attribute.gif',
                    label: filterManager.nodesDictionary["resourceTypes"] + '=' + resourceTypes
                });
                selectorNode.append(item);
            }

            var interfaces = selectors[selectorIndex].getElementsByTagName("interface");

            for (var interfaceIndex = 0; interfaceIndex < interfaces.length; interfaceIndex++) {
                var interfaceNode = new Jx.TreeFolder({
                    label: filterManager.nodesDictionary["interface"],
                    image: '/media/img/Others/ActionSheduler/interface.gif',
                    imageClass: 'simpleFolder',
                    open: true
                });
                selectorNode.append(interfaceNode);
                filterManager.attachAttributesTree(interfaceNode, interfaces[interfaceIndex]);
                var devices = interfaces[interfaceIndex].getElementsByTagName("device");
                for (var deviceIndex = 0; deviceIndex < devices.length; deviceIndex++) {
                    var deviceNode = new Jx.TreeFolder({
                        label: filterManager.nodesDictionary["device"],
                        image: '/media/img/Others/ActionSheduler/device.gif',
                        imageClass: 'simpleFolder',
                        open: true
                    });
                    filterManager.attachAttributesTree(deviceNode, devices[deviceIndex]);
                    interfaceNode.append(deviceNode);

                    var resources = devices[deviceIndex].getElementsByTagName("resource");
                    for (var resourceIndex = 0; resourceIndex < resources.length; resourceIndex++) {
                        var resourceNode = new Jx.TreeFolder({
                            label: filterManager.nodesDictionary["resource"],
                            image: '/media/img/Others/ActionSheduler/resource.gif',
                            imageClass: 'simpleFolder',
                            open: true
                        });
                        filterManager.attachAttributesTree(resourceNode, resources[resourceIndex]);
                        deviceNode.append(resourceNode);
                    }
                }
            }
            filterManager.previewTree.append(selectorNode);
        }
    },

    uniqueID: function() {
        var newDate = new Date;
        return newDate.getTime() + '';
    },

    getXMLFilters: function() {
        var txt = this.textArea.get('value');
        if (txt == "") {
            txt = "<filter culture=\"en-gb\"><selector/></filter>"; // Base filter
            this.textArea.set('value', txt);
        }
        if (window.DOMParser) { // No IE
            parser = new DOMParser();
            this.xmlDoc = parser.parseFromString(txt, "text/xml");
        }
        else // Internet Explorer
        {
            this.xmlDoc = new ActiveXObject("Microsoft.XMLDOM");
            this.xmlDoc.async = "false";
            this.xmlDoc.loadXML(txt);
        }
    }
};

var parametersManager = {
    initialize: function() {
        this.messagePanel = $('parameters_message_panel').setStyle('display', 'none');
        this.listPanel = $('parameters_list_panel').setStyle('display', 'none');
        this.addPanel = $('parameters_add_panel').setStyle('display', 'none');

        this.inputControl = $('cParam');
        this.addBtn = $('parameters_add_btn');
        this.addInputLabel = $('parameters_add_input_label');
        this.addInputValue = $('parameters_add_input_value');
        var self = this;

        this.addBtn.addEvent('click', parametersManager.addData);
    },

    displayData: function() {
        parametersManager.addPanel.setStyle('display', 'none');
        if (parametersManager.paramArray.length == 0) {
            parametersManager.messagePanel.setStyle('display', '');
            parametersManager.listPanel.setStyle('display', 'none');
            return;
        }
        parametersManager.messagePanel.setStyle('display', 'none');
        parametersManager.listPanel.setStyle('display', '');
        parametersManager.listPanel.set('html', '');

        var tbody = createTable(parametersManager.listPanel, [global_uiDictionary["Label"], global_uiDictionary["Value"]]);
        for (var index = 0; index < parametersManager.paramArray.length; index++) {
            var styleClass = '';
            if (index % 2 == 0)
                styleClass = 'odd';
            var tr = new Element('tr', { 'class': styleClass });
            var item = parametersManager.paramArray[index];

            var tdEntryLabel = new Element('td', { html: item.Label });
            tdEntryLabel.inject(tr);

            var tdEntryValue = new Element('td', { html: item.Value });
            tdEntryValue.inject(tr);

            tr.inject(tbody);
        }
    },

    editData: function() {
        parametersManager.addPanel.setStyle('display', '');
        if (parametersManager.paramArray.length == 0) {
            parametersManager.messagePanel.setStyle('display', '');
            parametersManager.listPanel.setStyle('display', 'none');
            return;
        }

        parametersManager.messagePanel.setStyle('display', 'none');
        parametersManager.listPanel.setStyle('display', '');
        parametersManager.listPanel.set('html', '');

        var tbody = createTable(parametersManager.listPanel, [global_uiDictionary["Label"], global_uiDictionary["Value"], ""]);

        for (var index = 0; index < parametersManager.paramArray.length; index++) {
            var styleClass = '';
            if (index % 2 == 0)
                styleClass = 'odd';
            var tr = new Element('tr', { 'class': styleClass });
            var item = parametersManager.paramArray[index];

            var tdEntryLabel = new Element('td', { html: item.Label });
            tdEntryLabel.inject(tr);

            var tdEntryValue = new Element('td', { html: item.Value });
            tdEntryValue.inject(tr);

            var tdAction = new Element('td', {});
            var img = new Element('img', {
                src: '../media/img/Others/ActionSheduler/remove_btn.gif',
                width: '20px',
                height: '20px'
            }
                    );

            var btn = new Element('a', {
                href: '#',
                'class': 'removeBtn'
            });
            btn.set('data-id', index);
            img.inject(btn);

            btn.addEvent('click', function(event) {
                var id = $(this).get('data-id');
                parametersManager.deleteItem(id);
                event.preventDefault();
            });

            btn.inject(tdAction);
            tdAction.inject(tr);
            tr.inject(tbody);
        }
    },

    resetDataEdit: function() {
        parametersManager.paramArray = new Array();
        //parametersManager.paramArray.push({ Label: '???', Value: '???' });
        parametersManager.editData();
    },

    loadDataEdit: function() {
        var params = JSON.decode(parametersManager.inputControl.get('value'));
        if (params == null || params.length <= 0) {
            parametersManager.resetDataEdit();
            return;
        }
        parametersManager.paramArray = params;
        parametersManager.editData();
    },

    loadDataDisplay: function() {
        var params = JSON.decode(parametersManager.inputControl.get('value'));
        if (params == null || params.length <= 0) {
            parametersManager.paramArray = new Array();
            parametersManager.displayData();
            return;
        }
        parametersManager.paramArray = params;
        parametersManager.displayData();
    },

    addData: function(event) {
        var label = parametersManager.addInputLabel.get('value');
        var value = parametersManager.addInputValue.get('value');
        event.preventDefault();
        if (label == "" || value == "") {
            return;
        }

        var itemSubstituted = false;
        for (var i = 0; i < parametersManager.paramArray.length; i++) {
            if (parametersManager.paramArray[i].Label == '???' || parametersManager.paramArray[i].Label == label) {
                parametersManager.paramArray[i].Label = label;
                parametersManager.paramArray[i].Value = value;
                itemSubstituted = true;
            }
        }
        if (!itemSubstituted) {
            var item = { Label: label, Value: value };
            parametersManager.paramArray.push(item);
        }

        parametersManager.editData();
    },

    saveData: function() {
        return JSON.encode(parametersManager.paramArray);
    },

    deleteItem: function(index) {
        var newArray = new Array();
        for (var i = 0; i < parametersManager.paramArray.length; i++) {
            if (i != index)
                newArray.push(parametersManager.paramArray[i]);
        }
        parametersManager.paramArray = newArray;
        //        if (parametersManager.paramArray.length <= 0)
        //            parametersManager.paramArray.push({ Label: '???', Value: '???' });
        parametersManager.editData();
    }
};

var ValidationControl = new Class({
    initialize: function(controlName, regString, isRequired, condition) {
        this.control = $(controlName);
        this.regString = regString;
        this.isRequired = isRequired;
        this.condition = condition;
        this.validator = new Element('span', {
            html: '*',
            'class': 'validatorSymbol'
        });
        this.validator.inject(this.control, 'after');
        this.validator.setStyle('display', 'none');
    },
    validate: function() {
        if (this.isRequired) {
            if (this.control.get('value') == "") {
                this.validator.setStyle('display', '');
                return false;
            } else {
                this.validator.setStyle('display', 'none');
                return true;
            }
        }
        if (this.regString != "") {
            var re = new RegExp(this.regString);
            if (!control.match(re)) {
                this.validator.setStyle('display', '');
                return false;
            } else {
                this.validator.setStyle('display', 'none');
                return true;
            }
        }
        if (this.condition != null) {
            var ok = this.condition();
            this.validator.setStyle('display', ok ? 'none' : '');
            return ok;
        }
    },

    reset: function() {
        this.validator.setStyle('display', 'none');
    }
});


var baseValidationManager = {
    initialize: function() {
        var self = this;
        this.validationControls = new Array();
    },

    addControl: function(controlID, regStr, isRequired) {
        var vc = new ValidationControl(controlID, regStr, isRequired);
        baseValidationManager.validationControls.push(vc);
    },
    validate: function(controlID) {
        var isValid = true;
        for (var index = 0; index < baseValidationManager.validationControls.length; index++) {
            if (!baseValidationManager.validationControls[index].validate()) {
                isValid = false;
            }
        }
        return isValid;
    },
    reset: function() {
        for (var index = 0; index < baseValidationManager.validationControls.length; index++) {
            baseValidationManager.validationControls[index].reset();
        }
    }
};

var timesManager = {
    initialize: function() {
        var self = this;

        this.messagePanel = $('times_message_panel').setStyle('display', 'none');
        this.listPanel = $('times_list_panel').setStyle('display', 'none');
        this.addPanel = $('times_add_panel').setStyle('display', 'none');

        this.inputControl = $('cTimes');
        this.addBtn = $('times_add_btn');
        this.addInput = $('times_add_input');

        this.timeArray = new Array();

        this.addBtn.addEvent('click', timesManager.addData);

        this.newTimePicker = new DatePicker('times_add_input', {
            pickerClass: 'datepicker_vista',
            timePicker: true,
            timePickerOnly: true,
            inputOutputFormat: 'H:i',
            format: 'H:i',
            allowEmpty: true
        });
    },

    saveData: function() {
        var serializedData = "";
        for (var i = 0; i < timesManager.timeArray.length; i++) {
            serializedData += timesManager.timeArray[i] + ' ';
        }
        var stringLength = serializedData.length;
        if (stringLength > 0)
            serializedData = serializedData.substring(0, stringLength - 1);
        return serializedData;
    },

    deleteTime: function(index) {
        var time = timesManager.timeArray[index];
        timesManager.timeArray.erase(time);
        //        if (timesManager.timeArray.length <= 0)
        //            timesManager.timeArray.push('01:00');
        timesManager.editData();
    },

    addElement: function(time) {
        if (!timesManager.timeArray.contains(time) && time != "") {
            timesManager.timeArray.push(time);
            timesManager.timeArray.sort();
            timesManager.editData();
        }
    },

    addData: function(event) {
        var currentTime = timesManager.addInput.get('value');
        timesManager.addElement(currentTime);
        event.preventDefault();
    },

    editData: function() {
        timesManager.addPanel.setStyle('display', '');
        if (timesManager.timeArray.length == 0) {
            timesManager.messagePanel.setStyle('display', '');
            timesManager.listPanel.setStyle('display', 'none');
            return;
        }

        timesManager.messagePanel.setStyle('display', 'none');
        timesManager.listPanel.setStyle('display', '');
        timesManager.listPanel.set('html', '');

        var tbody = createTable(timesManager.listPanel, [global_uiDictionary["Time"], ""]);

        for (var index = 0; index < timesManager.timeArray.length; index++) {
            var styleClass = '';
            if (index % 2 == 0)
                styleClass = 'odd';
            var tr = new Element('tr', { 'class': styleClass });
            var currentTime = timesManager.timeArray[index];
            var tdEntry = new Element('td', { html: currentTime });
            tdEntry.inject(tr);
            var tdAction = new Element('td', {});
            var img = new Element('img', {
                src: '../media/img/Others/ActionSheduler/remove_btn.gif',
                width: '20px',
                height: '20px'
            }
                    );

            var btn = new Element('a', {
                href: '#',
                'class': 'removeBtn'
            });
            btn.set('data-id', index);
            img.inject(btn);
            btn.addEvent('click', function(event) {
                var id = $(this).get('data-id');
                timesManager.deleteTime(id);
                event.preventDefault();
            });

            btn.inject(tdAction);
            tdAction.inject(tr);
            tr.inject(tbody);
        }
    },

    displayData: function() {
        timesManager.addPanel.setStyle('display', 'none');
        if (timesManager.timeArray.length == 0) {
            timesManager.messagePanel.setStyle('display', '');
            timesManager.listPanel.setStyle('display', 'none');
            return;
        }
        timesManager.messagePanel.setStyle('display', 'none');
        timesManager.listPanel.setStyle('display', '');
        timesManager.listPanel.set('html', '');

        var tbody = createTable(timesManager.listPanel, [global_uiDictionary["Time"]]);
        for (var index = 0; index < timesManager.timeArray.length; index++) {
            var styleClass = '';
            if (index % 2 == 0)
                styleClass = 'odd';
            var tr = new Element('tr', { 'class': styleClass });
            var currentTime = timesManager.timeArray[index];
            var tdEntry = new Element('td', { html: currentTime });
            tdEntry.inject(tr);
            tr.inject(tbody);
        }
    },
    resetDataEdit: function() {
        timesManager.timeArray = new Array();
        //timesManager.timeArray.push('01:00');
        timesManager.editData();
    },
    loadDataEdit: function() {
        var params = timesManager.inputControl.get('value');
        if (params == null || params.length <= 0) {
            timesManager.resetDataEdit();
            return;
        }
        timesManager.timeArray = timesManager.inputControl.get('value').split(" ");
        timesManager.editData();
    },

    loadDataDisplay: function() {
        var currentText = timesManager.inputControl.get('value');
        if (currentText == null || currentText.length <= 0) {
            timesManager.timeArray = new Array();
            timesManager.displayData();
            return;
        }
        timesManager.timeArray = timesManager.inputControl.get('value').split(" ");
        timesManager.displayData();
    }
};

var startDatePicker;
var retryTimeoutPicker;
var retryDurationPicker;
var periodPicker;
var myClientDataEntry;
var vcPeriodTime;
var vcPeriodInt;
var vcTimesList;
var vcCommand;
var vcWritingList;
var vcMapFileName;
function openPreview() {
    // [GREGOR] Point to Preview URL
    var scheduledActionID = myClientDataEntry.getRecordID();
    window.open('/Settings/FilterPreview.aspx' + '?scheduledActionID=' + scheduledActionID, 'Preview');
}

function update_action_visibility() {
    var selectedType = $('cActionType').selectedIndex;
    if (selectedType == 0) {// ScheduledCommand
        $('gCommand').setStyle('display', '');
        $('gArgs').setStyle('display', '');
        $('gParamMain').setStyle('display', 'none');
        $('gParamFileName').setStyle('display', 'none');
        $('gParameters').setStyle('display', 'none');
    }
    else //ScheduledParameterWriting
    {
        $('gCommand').setStyle('display', 'none');
        $('gArgs').setStyle('display', 'none');
        $('gParamMain').setStyle('display', '');
        update_parmaWriter_visibility();
    }
}

function update_parmaWriter_visibility() {
    var selectedType = $('cParamType').selectedIndex;
    var selectedTypeAction = $('cActionType').selectedIndex;
    if (selectedTypeAction == 0) {
        $('gParamFileName').setStyle('display', 'none');
        $('gParameters').setStyle('display', 'none');
        return;
    }
    if (selectedType == 0) {// File Name
        $('gParamFileName').setStyle('display', '');
        $('gParameters').setStyle('display', 'none');
    }
    else if (selectedType == 1) {//Parameters
        $('gParamFileName').setStyle('display', 'none');
        $('gParameters').setStyle('display', '');
    }
}

function update_schedule_visibility() {
    var selectedType = $('cScheduleType').selectedIndex;
    if (selectedType == 0) {//Periodic
        $('gcPeriodTime').setStyle('display', '');
        $('gcPeriodInt').setStyle('display', 'none');
        $('panel_times').setStyle('display', 'none');
        $('panel_days').setStyle('display', 'none');
    }
    else if (selectedType == 1) {// Daily
        $('gcPeriodTime').setStyle('display', 'none');
        $('gcPeriodInt').setStyle('display', '');
        $('panel_times').setStyle('display', '');
        $('panel_days').setStyle('display', 'none');
    }
    else {// Weekly
        $('gcPeriodTime').setStyle('display', 'none');
        $('gcPeriodInt').setStyle('display', '');
        $('panel_times').setStyle('display', '');
        $('panel_days').setStyle('display', '');
    }
}

function setVisibility(array, value) {
    for (i = 0; i < array.length; i++) {
        $(array[i]).style.display = value;
    }
}

function selectValue(control, value) {
    for (i = 0; i < control.length; i++) {
        if (control.options[i].value == value) {
            control.selectedIndex = i;
        }
    }
}

function details_onSelect(event) {

    myClientDataEntry.exeRecordSelect(event);
    // Preview
    var previewBtn = document.getElement('div.wkaToolbarArea td.dosome a.watGenericPreview');
    previewBtn.removeClass('disabled');

    // Update Piker values
    retryTimeoutPicker.refreshValue($('cRetryTimeout').get('value'));
    retryDurationPicker.refreshValue($('cRetryDuration').get('value'));
    periodPicker.refreshValue($('cPeriodTime').get('value'));
    startDatePicker.refreshValue($('cStartDate').get('value'));

    // Load Data
    timesManager.loadDataDisplay();
    parametersManager.loadDataDisplay();
    filterManager.loadData();

    baseValidationManager.reset();

}

function reset() {
    $('cActionType').selectedIndex = 0;
    $('cScheduleType').selectedIndex = 0;
    $('cParamType').selectedIndex = 0;

    update_parmaWriter_visibility();
    update_action_visibility();
    update_schedule_visibility();

    $('cFilters').set('value', '');

    filterManager.loadData();
    baseValidationManager.reset();
}

function details_onAdd() {
    reset();

    // Initialize Defaults      
    $('cRetryDuration').set('value', '01:00:00');
    retryDurationPicker.refreshValue($('cRetryDuration').get('value'));

    $('cRetryTimeout').set('value', '00:05:00');
    retryTimeoutPicker.refreshValue($('cRetryTimeout').get('value'));

    $('cPeriodInt').set('value', '1');

    timesManager.resetDataEdit();
    parametersManager.resetDataEdit();
}

function details_onCancel() {
    reset();
    // Load Data
    timesManager.loadDataDisplay();
    parametersManager.loadDataDisplay();
}

function details_onSave(event) {
    $('cTimes').set('value', timesManager.saveData());
    $('cParam').set('value', parametersManager.saveData());

    var baseValidation = baseValidationManager.validate();

    // Validate Retry
    var scheduleSelectedIndex = $('cScheduleType').selectedIndex;
    var retryValidation = true;
    if (scheduleSelectedIndex == 0) { // Periodic
        retryValidation = vcPeriodTime.validate();
    }
    else if (scheduleSelectedIndex == 1) { // Daily
        retryValidation = vcPeriodInt.validate() && vcTimesList.validate();
    }
    else { // Weekly
        retryValidation = vcPeriodInt.validate() && vcTimesList.validate();
    }

    // Validate Action
    var actionValidation = true;
    var actionSelectedIndex = $('cActionType').selectedIndex;
    if (actionSelectedIndex == 0) {// Command
        actionValidation = vcCommand.validate();
    }
    else {// write parameters

        var paramSelectedIndex = $('cParamType').selectedIndex;
        if (paramSelectedIndex == 0) {// File Map
            actionValidation = vcMapFileName.validate();
        }
        else { // Param Write
            actionValidation = vcWritingList.validate();
        }
    }
    if (baseValidation && retryValidation && actionValidation)
        myClientDataEntry.exeToolbarButton(event);

    return true;
}

function details_onEdit() {
    // Load Data
    timesManager.loadDataEdit();
    parametersManager.loadDataEdit();
    commandArgumentsManager.loadDataEdit();
}

function onlyDigits(e) {
    if (e.event.keyCode == 46 || e.event.keyCode == 8 || e.event.keyCode == 37 || e.event.keyCode == 39) {
        return true;
    }
    if (e.event.keyCode < 95) {
        if (e.event.keyCode < 48 || e.event.keyCode > 57) {
            e.stop();
            return false;
        }
    }
    else {
        if (e.event.keyCode < 96 || e.event.keyCode > 105) {
            e.stop();
            return false;
        }
    }
}

window.addEvent('domready', function() {
    if (Browser.ie == true && Browser.version < 9) {
        $('ToolBar1$ilbEdit').addEvent('click', details_onEdit);
        $('ToolBar1$ilbAdd').addEvent('click', details_onAdd);
        $('ToolBar1$ilbCancel').addEvent('click', details_onCancel);
    }

    myClientDataEntry = new clientDataEntry('list');

    if (Browser.ie == null || (Browser.ie == true && Browser.version >= 9)) {
        $('ToolBar1$ilbEdit').addEvent('click', details_onEdit);
        $('ToolBar1$ilbAdd').addEvent('click', details_onAdd);
        $('ToolBar1$ilbCancel').addEvent('click', details_onCancel);
    }

    $('ToolBar1$ilbSave').removeEvents();
    $('ToolBar1$ilbSave').addEvent('click', details_onSave);

    var previewBtn = document.getElement('div.wkaToolbarArea td.dosome a.watGenericPreview');
    previewBtn.addClass('disabled');
    previewBtn.addEvent('click', openPreview);
    previewBtn.onclick = function() { return false; }

    for (i = 0; i < myClientDataEntry.cdeRecordListItemStores.length; i++) {
        var crow = myClientDataEntry.cdeRecordListItemStores[i].getFirstParentByTag('tr');
        var clnk = crow.getElement('a');
        clnk.removeEvents();
        clnk.addEvent('click', details_onSelect);
    }

    $('cRetryTimeout').setStyle('width', '90px');
    $('cRetryDuration').setStyle('width', '90px');
    $('cPeriodTime').setStyle('width', '90px');
    $('cStartDate').setStyle('width', '160px');
    $('cPeriodInt').setStyle('width', '80px');
    $('cPeriodInt').addEvents({
        'keydown': onlyDigits
    });
    retryTimeoutPicker = new TimeSpanPicker('cRetryTimeout',
            {
                pickerClass: 'datepicker_vista',
                allowEmpty: true,
                titleMessage: global_uiDictionary["ts_SetMessage"],
                formatMessage: global_uiDictionary["ts_FormatMessage"],
                confirmText: global_uiDictionary["ts_confirmText"],
                debug: false
            });

    retryDurationPicker = new TimeSpanPicker('cRetryDuration',
            {
                pickerClass: 'datepicker_vista',
                allowEmpty: true,
                titleMessage: global_uiDictionary["ts_SetMessage"],
                formatMessage: global_uiDictionary["ts_FormatMessage"],
                confirmText: global_uiDictionary["ts_confirmText"],
                debug: false
            });

    periodPicker = new TimeSpanPicker('cPeriodTime',
            {
                pickerClass: 'datepicker_vista',
                allowEmpty: true,
                titleMessage: global_uiDictionary["ts_SetMessage"],
                formatMessage: global_uiDictionary["ts_FormatMessage"],
                confirmText: global_uiDictionary["ts_confirmText"],
                debug: false
            });

    startDatePicker = new DatePicker('cStartDate', {
        pickerClass: 'datepicker_vista',
        timePicker: true,
        inputOutputFormat: 'd-m-Y @ H:i',
        format: 'd-m-Y @ H:i',
        allowEmpty: true,
        days: global_daysOfWeekDictionary,
        months: global_monthsDictionary,
        selectTimeMessage: global_uiDictionary["date_selectTimeMessage"],
        confirmText: global_uiDictionary["date_ok"],
        debug: false
    });

    timesManager.initialize();
    parametersManager.initialize();
    commandArgumentsManager.initialize();

    filterManager.initialize(global_selectorTypes, global_resourceTypes, global_interfaceAttributeArray, global_deviceAttributeArray, global_interfaceArray, global_uiDictionary, global_nodesDictionary);

    update_schedule_visibility();
    update_action_visibility();
    update_parmaWriter_visibility();

    $('cScheduleType').addEvent('change', update_schedule_visibility);
    $('cActionType').addEvent('change', update_action_visibility);
    $('cParamType').addEvent('change', update_parmaWriter_visibility);

    baseValidationManager.initialize();
    baseValidationManager.addControl('cRetryTimeout', '', true, null);
    baseValidationManager.addControl('cRetryDuration', '', true, null);
    baseValidationManager.addControl('cStartDate', '', true, null);
    baseValidationManager.addControl('cName', '', true, null);

    vcPeriodTime = new ValidationControl('cPeriodTime', '', true, null);
    vcPeriodInt = new ValidationControl('cPeriodInt', '', true, null);
    vcTimesList = new ValidationControl('time_emptyMessage', '', false, function() { return $('times_message_panel').style.display == 'none' });

    vcCommand = new ValidationControl('decCommand', '', true, null);
    // A validation for command arguments should be introduced.    

    vcMapFileName = new ValidationControl('cParamFileName', '', true, null);
    vcWritingList = new ValidationControl('param_emptyMessage', '', false, function() { return $('parameters_message_panel').style.display == 'none' });

    $('cFilters').set('value', '');
});                           